Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/editors/space_outliner/outliner_tools.c')
-rw-r--r--source/blender/editors/space_outliner/outliner_tools.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/source/blender/editors/space_outliner/outliner_tools.c b/source/blender/editors/space_outliner/outliner_tools.c
index 2a13f9d6a66..01b6e636ded 100644
--- a/source/blender/editors/space_outliner/outliner_tools.c
+++ b/source/blender/editors/space_outliner/outliner_tools.c
@@ -981,7 +981,7 @@ static void singleuser_world_fn(bContext *C,
}
/**
* \param select_recurse: Set to false for operations which are already
* recursively operating on their children.
*/
void outliner_do_object_operation_ex(bContext *C,
@@ -991,7 +991,7 @@ void outliner_do_object_operation_ex(bContext *C,
ListBase *lb,
outliner_operation_fn operation_fn,
void *user_data,
- bool select_recurse)
+ bool recurse_selected)
{
TreeElement *te;
for (te = lb->first; te; te = te->next) {
@@ -1013,7 +1013,7 @@ void outliner_do_object_operation_ex(bContext *C,
}
}
if (TSELEM_OPEN(tselem, space_outliner)) {
- if ((select_handled == false) || select_recurse) {
+ if ((select_handled == false) || recurse_selected) {
outliner_do_object_operation_ex(C,
reports,
scene_act,
@@ -1021,7 +1021,7 @@ void outliner_do_object_operation_ex(bContext *C,
&te->subtree,
operation_fn,
NULL,
- select_recurse);
+ recurse_selected);
}
}
}
@@ -981,7 +981,7 @@ static void singleuser_world_fn(bContext *C,
}
/**
- * \param select_recurse: Set to false for operations which are already
+ * \param recurse_selected: Set to false for operations which are already
* recursively operating on their children.
*/